/**
 * Copyright (c) 2014 David I. Bell
 * Permission is granted to use, distribute, or modify this source,
 * provided that this copyright notice remains intact.
 */
package weather;

import weather.gui.MainWindow;


public class Main
{
	static public void main(String[] args)
	{
		Main main = new Main();

		main.run(args);
	}


	public void run(String[] args)
	{
		boolean isDaemon = false;
		boolean isUpdate = false;
		String configFile = "weather.properties";

		for (int index = 0; index < args.length; index++)
		{
			String arg = args[index];

			if (arg.equals("-daemon"))
				isDaemon = true;
			else if (arg.equals("-update"))
				isUpdate = true;
			else if (arg.startsWith("-"))
				usage();
			else
				configFile = arg;
		}

		//
		// Read the properties from the specified configuration file.
		//
		Configuration.getInstance().loadProperties(configFile);

		//
		// If we are running as a daemon then do that.
		//
		Controller controller = new Controller();

		if (isDaemon || isUpdate)
		{
			controller.runDaemon(isUpdate);

			return;
		}

		//
		// We are not in daemon mode so create the top level GUI.
		// This runs in another persistent thread so we can just return.
		//
		new MainWindow(controller);

		//
		// Initialise with the first report and observation type.
		//
//		controller.setSelector(Selector.AIR_TEMP_SELECTOR);
		controller.setReport(Configuration.getInstance().getInitialSite());

		//
		// Start the thread which runs the automatic updates.
		//
		controller.startAutomaticUpdates();
	}


	private void usage()
	{
		System.err.println("Usage: weather [-daemon] [-update] [configFile]");
		System.exit(1);
	}
}
